##### Source

<a href="https://commons.wikimedia.org/wiki/File:Apollo_11_liftoff_(48334428021).jpg">https://commons.wikimedia.org/wiki/File:Apollo_11_liftoff\_(48334428021).jpg</a>

##### Resized

[Apollo_11_liftoff.png](Apollo_11_liftoff.png)

##### License

public domain
